# Copyright 2013 Canonical Limited
from bzrlib.errors import UnknownFormatError, NotBranchError

from mocker import MockerTestCase, ANY
from bzrviews.helpers import get_bzr_revision


class BzrVersionTest(MockerTestCase):

    def test_get_bzr_revision(self):
        """
        We should get an integer value back for the revision.
        """
        self.assertIsInstance(get_bzr_revision(), int)

    def test_unknown_format_error(self):
        """
        If an L{UnknownFormatError} is raised when the Bazaar branch
        is opened, to get the revision number, the revision number
        will be reported as None.
        """
        error = UnknownFormatError("new-format")
        mock = self.mocker.replace("bzrlib.branch.Branch")
        mock.open_containing(ANY)
        self.mocker.throw(error)
        self.mocker.replay()
        self.assertEquals(get_bzr_revision(), None)

    def test_not_branch_error(self):
        """
        If an L{NotBranchError} is raised when the Bazaar branch
        is opened, to get the revision number, the revision number
        will be reported as None.
        """
        error = NotBranchError("/tmp")
        mock = self.mocker.replace("bzrlib.branch.Branch")
        mock.open_containing(ANY)
        self.mocker.throw(error)
        self.mocker.replay()
        self.assertEquals(get_bzr_revision(), None)
